@@ -23,6 +23,7 @@ from termcolor import colored, cprint
 from django.conf import settings
 from django.core.management.base import BaseCommand, CommandError
 from django.core.management import call_command
+from django.contrib.auth import get_user_model
 
 from Iuno import DEVELOPMENT, STAGE, PRODUCTION
 from Iuppiter.Util import classForName
@@ -65,7 +66,8 @@ class Command(BaseCommand):
         # Iuno initialdata
         initialData = hasattr(settings, 'IUNO_INITIAL_DATA')
         
-        if initialData:
+        User = get_user_model()
+        if initialData and not User.objects.all().exists():
             initialData = settings.IUNO_INITIAL_DATA
             if os.path.exists(initialData):
                 call_command('loaddata', initialData)
